@@ -1,4 +1,4 @@
-package Pcore::Chrome v0.11.1;
+package Pcore::Chrome v0.12.0;
 
 use Pcore -dist, -class, -res, -const;
 use Pcore::Chrome::Tab;
@@ -13,6 +13,7 @@ has useragent     => ();
 has _proc => ();
 
 # https://chromedevtools.github.io/devtools-protocol/tot/
+# https://peter.sh/experiments/chromium-command-line-switches/
 
 const our $CHECK_PORT_TIMEOUT => 0.1;
 const our $CONNECT_TIMEOUT    => 10;
@@ -54,6 +55,7 @@ around new => sub ( $orig, $self, %args ) {
         '--window-size=1280x720',
 
         '--disable-default-apps',
+        '--no-default-browser-check',
         '--no-first-run',
         '--disable-infobars',
         '--disable-popup-blocking',
@@ -81,7 +83,7 @@ around new => sub ( $orig, $self, %args ) {
         $user_args ? $user_args->@* : (),
 
         # open "about:blank" by default
-        'about:blank',
+        # 'about:blank',
 
         # redirect STDERR under linux
         !$MSWIN ? '2>/dev/null' : (),
@@ -131,9 +133,9 @@ sub new_tab ( $self, $url = undef ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 78                   | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
+## |    2 | 80                   | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 90                   | CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              |
+## |    1 | 92                   | CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
